==> owncloud-10.0.3.tgz: owncloud/settings/l10n/km.js <==
OC.L10N.register(
    "settings",
    {
    "Wrong password" : "ខុស​ពាក្យ​សម្ងាត់",
    "Authentication error" : "កំហុស​ការ​ផ្ទៀង​ផ្ទាត់​ភាព​ត្រឹម​ត្រូវ",
    "Saved" : "បាន​រក្សាទុក",
    "test email settings" : "សាក​ល្បង​ការ​កំណត់​អ៊ីមែល",
    "Email sent" : "បាន​ផ្ញើ​អ៊ីមែល",
    "You need to set your user email before being able to send test emails." : "អ្នក​ត្រូវ​តែ​កំណត់​អ៊ីមែល​របស់​អ្នក​មុន​នឹង​អាច​ផ្ញើ​អ៊ីមែល​សាកល្បង​បាន។",
    "__language_name__" : "__language_name__",
    "Language changed" : "បាន​ប្ដូរ​ភាសា",
    "Invalid request" : "សំណើ​មិន​ត្រឹម​ត្រូវ",
    "Admins can't remove themself from the admin group" : "អ្នក​គ្រប់​គ្រង​មិន​អាច​លុប​ខ្លួន​ឯង​ចេញ​ពី​ក្រុម​អ្នក​គ្រប់​គ្រង​ឡើយ",
    "Unknown user" : "មិនស្គាល់អ្នកប្រើប្រាស់",
    "All" : "ទាំងអស់",
    "Enabled" : "បាន​បើក",
    "Please wait...." : "សូម​រង់​ចាំ....",
    "Error while disabling app" : "មាន​កំហុស​ពេល​កំពុង​បិទកម្មវិធី",
    "Disable" : "បិទ",
    "Enable" : "បើក",
    "Updating...." : "កំពុង​ធ្វើ​បច្ចុប្បន្នភាព....",
    "Error while updating app" : "មាន​កំហុស​ពេល​ធ្វើ​បច្ចុប្បន្នភាព​កម្មវិធី",
    "Updated" : "បាន​ធ្វើ​បច្ចុប្បន្នភាព",
    "Delete" : "លុប",
    "Sending..." : "កំពុង​ផ្ញើ...",
    "Select a profile picture" : "ជ្រើស​រូបភាព​ប្រវត្តិរូប",
    "Very weak password" : "ពាក្យ​សម្ងាត់​ខ្សោយ​ណាស់",
    "Weak password" : "ពាក្យ​សម្ងាត់​ខ្សោយ",
    "So-so password" : "ពាក្យ​សម្ងាត់​ធម្មតា",
    "Good password" : "ពាក្យ​សម្ងាត់​ល្អ",
    "Strong password" : "ពាក្យ​សម្ងាត់​ខ្លាំង",
    "Groups" : "ក្រុ",
    "undo" : "មិន​ធ្វើ​វិញ",
    "never" : "មិនដែរ",
    "add group" : "បន្ថែម​ក្រុម",
    "A valid username must be provided" : "ត្រូវ​ផ្ដល់​ឈ្មោះ​អ្នក​ប្រើ​ឲ្យ​បាន​ត្រឹម​ត្រូវ",
    "A valid password must be provided" : "ត្រូវ​ផ្ដល់​ពាក្យ​សម្ងាត់​ឲ្យ​បាន​ត្រឹម​ត្រូវ",
    "Forum" : "វេទិកាពិភាក្សា",
    "Sharing" : "ការ​ចែក​រំលែក",
    "Allow apps to use the Share API" : "អនុញ្ញាត​ឲ្យ​កម្មវិធី​ប្រើ API ចែក​រំលែក",
    "Allow public uploads" : "អនុញ្ញាត​ការ​ផ្ទុក​ឡើង​ជា​សាធារណៈ",
    "Allow resharing" : "អនុញ្ញាត​ការ​ចែក​រំលែក​ម្ដង​ទៀត",
    "Log" : "Log",
    "None" : "គ្មាន",
    "Login" : "ចូល",
    "Encryption" : "កូដនីយកម្ម",
    "From address" : "ពី​អាសយដ្ឋាន",
    "Server address" : "អាសយដ្ឋាន​ម៉ាស៊ីន​បម្រើ",
    "Port" : "ច្រក",
    "Send email" : "ផ្ញើ​អ៊ីមែល",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "ខ្វះ​ម៉ូឌុល 'fileinfo' ។ យើង​សូម​ណែនាំ​ឲ្យ​បើក​ម៉ូឌុល​នេះ ដើម្បី​ទទួល​បាន​លទ្ធផល​ល្អ​នៃ​ការ​សម្គាល់​ប្រភេទ mime ។",
    "Get the apps to sync your files" : "ដាក់​អោយកម្មវិធីផ្សេងៗ ​ធ្វើសមកាលកម្ម​ឯកសារ​អ្នក",
    "Show First Run Wizard again" : "បង្ហាញ First Run Wizard ម្តង​ទៀត",
    "Profile picture" : "រូបភាព​ប្រវត្តិរូប",
    "Upload new" : "ផ្ទុកឡើង​ថ្មី",
    "Remove image" : "ដក​រូបភាព​ចេញ",
    "Cancel" : "លើកលែង",
    "Email" : "អ៊ីមែល",
    "Your email address" : "អ៊ីម៉ែល​របស់​អ្នក",
    "Password" : "ពាក្យសម្ងាត់",
    "Unable to change your password" : "មិន​អាច​ប្ដូរ​ពាក្យ​សម្ងាត់​របស់​អ្នក​បាន​ទេ",
    "Current password" : "ពាក្យសម្ងាត់​បច្ចុប្បន្ន",
    "New password" : "ពាក្យ​សម្ងាត់​ថ្មី",
    "Change password" : "ប្តូរ​ពាក្យសម្ងាត់",
    "Language" : "ភាសា",
    "Help translate" : "ជួយ​បក​ប្រែ",
    "Unlimited" : "មិន​កំណត់",
    "Name" : "ឈ្មោះ",
    "Username" : "ឈ្មោះ​អ្នកប្រើ",
    "Version" : "កំណែ",
    "Personal" : "ផ្ទាល់​ខ្លួន",
    "Admin" : "អ្នក​គ្រប់​គ្រង",
    "Error" : "កំហុស",
    "Create" : "បង្កើត",
    "Admin Recovery Password" : "ការ​ស្វែង​រក​ពាក្យ​សម្ងាត់របស់ប្រធាន​វេបសាយ",
    "Other" : "ផ្សេងៗ",
    "set new password" : "កំណត់​ពាក្យ​សម្ងាត់​ថ្មី",
    "Default" : "លំនាំ​ដើម"
},
"nplurals=1; plural=0;");

==> owncloud-10.0.10.tgz: owncloud/settings/l10n/km.js <==
OC.L10N.register(
    "settings",
    {
    "Wrong password" : "ខុស​ពាក្យ​សម្ងាត់",
    "Authentication error" : "កំហុស​ការ​ផ្ទៀង​ផ្ទាត់​ភាព​ត្រឹម​ត្រូវ",
    "Saved" : "បាន​រក្សាទុក",
    "test email settings" : "សាក​ល្បង​ការ​កំណត់​អ៊ីមែល",
    "Email sent" : "បាន​ផ្ញើ​អ៊ីមែល",
    "You need to set your user email before being able to send test emails." : "អ្នក​ត្រូវ​តែ​កំណត់​អ៊ីមែល​របស់​អ្នក​មុន​នឹង​អាច​ផ្ញើ​អ៊ីមែល​សាកល្បង​បាន។",
    "__language_name__" : "__language_name__",
    "Language changed" : "បាន​ប្ដូរ​ភាសា",
    "Invalid request" : "សំណើ​មិន​ត្រឹម​ត្រូវ",
    "Admins can't remove themself from the admin group" : "អ្នក​គ្រប់​គ្រង​មិន​អាច​លុប​ខ្លួន​ឯង​ចេញ​ពី​ក្រុម​អ្នក​គ្រប់​គ្រង​ឡើយ",
    "Unknown user" : "មិនស្គាល់អ្នកប្រើប្រាស់",
    "All" : "ទាំងអស់",
    "Enabled" : "បាន​បើក",
    "Please wait...." : "សូម​រង់​ចាំ....",
    "Error while disabling app" : "មាន​កំហុស​ពេល​កំពុង​បិទកម្មវិធី",
    "Disable" : "បិទ",
    "Enable" : "បើក",
    "Updating...." : "កំពុង​ធ្វើ​បច្ចុប្បន្នភាព....",
    "Error while updating app" : "មាន​កំហុស​ពេល​ធ្វើ​បច្ចុប្បន្នភាព​កម្មវិធី",
    "Updated" : "បាន​ធ្វើ​បច្ចុប្បន្នភាព",
    "Delete" : "លុប",
    "Sending..." : "កំពុង​ផ្ញើ...",
    "Select a profile picture" : "ជ្រើស​រូបភាព​ប្រវត្តិរូប",
    "Very weak password" : "ពាក្យ​សម្ងាត់​ខ្សោយ​ណាស់",
    "Weak password" : "ពាក្យ​សម្ងាត់​ខ្សោយ",
    "So-so password" : "ពាក្យ​សម្ងាត់​ធម្មតា",
    "Good password" : "ពាក្យ​សម្ងាត់​ល្អ",
    "Strong password" : "ពាក្យ​សម្ងាត់​ខ្លាំង",
    "Groups" : "ក្រុ",
    "undo" : "មិន​ធ្វើ​វិញ",
    "never" : "មិនដែរ",
    "add group" : "បន្ថែម​ក្រុម",
    "A valid username must be provided" : "ត្រូវ​ផ្ដល់​ឈ្មោះ​អ្នក​ប្រើ​ឲ្យ​បាន​ត្រឹម​ត្រូវ",
    "A valid password must be provided" : "ត្រូវ​ផ្ដល់​ពាក្យ​សម្ងាត់​ឲ្យ​បាន​ត្រឹម​ត្រូវ",
    "Forum" : "វេទិកាពិភាក្សា",
    "Sharing" : "ការ​ចែក​រំលែក",
    "Allow apps to use the Share API" : "អនុញ្ញាត​ឲ្យ​កម្មវិធី​ប្រើ API ចែក​រំលែក",
    "Allow public uploads" : "អនុញ្ញាត​ការ​ផ្ទុក​ឡើង​ជា​សាធារណៈ",
    "Allow resharing" : "អនុញ្ញាត​ការ​ចែក​រំលែក​ម្ដង​ទៀត",
    "Log" : "Log",
    "None" : "គ្មាន",
    "Login" : "ចូល",
    "Encryption" : "កូដនីយកម្ម",
    "From address" : "ពី​អាសយដ្ឋាន",
    "Server address" : "អាសយដ្ឋាន​ម៉ាស៊ីន​បម្រើ",
    "Port" : "ច្រក",
    "Send email" : "ផ្ញើ​អ៊ីមែល",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "ខ្វះ​ម៉ូឌុល 'fileinfo' ។ យើង​សូម​ណែនាំ​ឲ្យ​បើក​ម៉ូឌុល​នេះ ដើម្បី​ទទួល​បាន​លទ្ធផល​ល្អ​នៃ​ការ​សម្គាល់​ប្រភេទ mime ។",
    "Get the apps to sync your files" : "ដាក់​អោយកម្មវិធីផ្សេងៗ ​ធ្វើសមកាលកម្ម​ឯកសារ​អ្នក",
    "Show First Run Wizard again" : "បង្ហាញ First Run Wizard ម្តង​ទៀត",
    "Profile picture" : "រូបភាព​ប្រវត្តិរូប",
    "Upload new" : "ផ្ទុកឡើង​ថ្មី",
    "Remove image" : "ដក​រូបភាព​ចេញ",
    "Cancel" : "លើកលែង",
    "Email" : "អ៊ីមែល",
    "Your email address" : "អ៊ីម៉ែល​របស់​អ្នក",
    "Password" : "ពាក្យសម្ងាត់",
    "Unable to change your password" : "មិន​អាច​ប្ដូរ​ពាក្យ​សម្ងាត់​របស់​អ្នក​បាន​ទេ",
    "Current password" : "ពាក្យសម្ងាត់​បច្ចុប្បន្ន",
    "New password" : "ពាក្យ​សម្ងាត់​ថ្មី",
    "Change password" : "ប្តូរ​ពាក្យសម្ងាត់",
    "Language" : "ភាសា",
    "Help translate" : "ជួយ​បក​ប្រែ",
    "Unlimited" : "មិន​កំណត់",
    "Name" : "ឈ្មោះ",
    "Username" : "ឈ្មោះ​អ្នកប្រើ",
    "Version" : "កំណែ",
    "Personal" : "ផ្ទាល់​ខ្លួន",
    "Admin" : "អ្នក​គ្រប់​គ្រង",
    "Error" : "កំហុស",
    "Create" : "បង្កើត",
    "Admin Recovery Password" : "ការ​ស្វែង​រក​ពាក្យ​សម្ងាត់របស់ប្រធាន​វេបសាយ",
    "Other" : "ផ្សេងៗ",
    "set new password" : "កំណត់​ពាក្យ​សម្ងាត់​ថ្មី",
    "Default" : "លំនាំ​ដើម",
    "Share" : "ចែក​រំលែក",
    "Add" : "បន្ថែម"
},
"nplurals=1; plural=0;");
